@@ -10,7 +10,8 @@ Net::Blogger::Engine::Blogger - Pyra Blogger API engine
 
 =head1 DESCRIPTION
 
-This package inherits I<Net::Blogger::Engine::Base> and defines methods specific the the Pyra (blogger.com) XML-RPC server.
+This package inherits I<Net::Blogger::Engine::Base> and defines methods specific 
+the the Pyra (blogger.com) XML-RPC server.
 
 =cut
 
@@ -20,7 +21,7 @@ use strict;
 use constant BLOGGER_PROXY  => "http://plant.blogger.com/api/RPC2";
 use constant MAX_POSTLENGTH => 65536;
 
-$Net::Blogger::Engine::Blogger::VERSION   = '0.1.3';
+$Net::Blogger::Engine::Blogger::VERSION   = '0.21';
 @Net::Blogger::Engine::Blogger::ISA       = qw ( Exporter Net::Blogger::Engine::Base );
 @Net::Blogger::Engine::Blogger::EXPORT    = qw ();
 @Net::Blogger::Engine::Blogger::EXPORT_OK = qw ();
@@ -41,7 +42,7 @@ sub new {
     return $self;
 }
 
-=head1 PUBLIC MEHODS
+=head1 OBJECT MEHODS
 
 =cut
 
@@ -54,7 +55,8 @@ Return the URI of the Blogger XML-RPC proxy
 =cut
 
 sub Proxy {
-    return BLOGGER_PROXY;
+  my $self = shift;
+  return $self->SUPER::Proxy(@_) || BLOGGER_PROXY;
 }
 
 =head2 $pkg->MaxPostLength()
@@ -73,19 +75,28 @@ sub DESTROY {
 
 =head1 KNOWN ISSUES
 
-=over
+=over 4
 
 =item *
 
 B<Delays>
 
-It remains uncertain how long a program needs to wait between the time that a new post is submitted to the Blogger servers and that that may post may be acted upon. The applies to the Blogger API I<getPost>, I<editPost> and I<deletePost> methods equally. Anything under a 10 second will often result in a "post not found" fault. A delay of 10 seconds or more is usually successful. Your mileage may vary.
+It remains uncertain how long a program needs to wait between the time that a new 
+post is submitted to the Blogger servers and that that may post may be acted upon. 
+
+The applies to the Blogger API I<getPost>, I<editPost> and I<deletePost> methods equally. 
+Anything under a 10 second will often result in a "post not found" fault. A delay of 10 
+seconds or more is usually successful. Your mileage may vary.
 
 =item *
 
 B<setTemplate()>
 
-<quote src = "ev">There are some blogs for which setTemplate will return a permission denied error. Newly created blogs will work. Sufficiently older blogs will work. A meanwhile work-around: edit the template through Blogger UI first.</quote>
+ <quote src = "ev">
+  There are some blogs for which setTemplate will return a permission denied error. Newly 
+  created blogs will work. Sufficiently older blogs will work. A meanwhile work-around: 
+  edit the template through Blogger UI first.
+ </quote>
 
 =back
 
@@ -93,58 +104,16 @@ B<setTemplate()>
 
 =head1 VERSION
 
-0.1.3
+0.21
 
 =head1 DATE
 
-May 04, 2002
+$Date: 2003/03/04 23:57:04 $
 
 =head1 AUTHOR
 
 Aaron Straup Cope
 
-=head1 CHANGES
-
-=head2 0.1.3
-
-=over
-
-=item *
-
-Added quotes to I<$VERSION>
-
-=back
-
-=head2 0.1.2
-
-=over
-
-=item *
-
-Updated POD
-
-=back
-
-=head2 0.1.1
-
-=over
-
-=item * 
-
-Updated POD
-
-=back
-
-=head2 0.1
-
-=over
-
-=item *
-
-Initial revision. 
-
-=back
-
 =head1 SEE ALSO
 
 L<Net::Blogger::Engine::Base>
@@ -153,7 +122,7 @@ http://plant.blogger.com/api/
 
 =head1 LICENSE
 
-Copyright (c) 2001-2002 Aaron Straup Cope.
+Copyright (c) 2001-2003 Aaron Straup Cope.
 
 This is free software, you may use it and distribute it under the
 same terms as Perl itself.
